@@ -1,10 +1,19 @@
+# -*- coding: utf-8 -*-
+"""
+github3.gists.comment
+---------------------
+
+Module containing the logic for a GistComment
+
+"""
+
 from github3.models import BaseComment
 from github3.users import User
 
 
 class GistComment(BaseComment):
-    """The :class:`GistComment <GistComment>` object. This represents a comment
-    on a gist.
+
+    """This object represents a comment on a gist.
 
     Two comment instances can be checked like so::
 
@@ -17,11 +26,14 @@ class GistComment(BaseComment):
         c1.id != c2.id
 
     See also: http://developer.github.com/v3/gists/comments/
+
     """
+
     def __init__(self, comment, session=None):
         super(GistComment, self).__init__(comment, session)
 
         #: :class:`User <github3.users.User>` who made the comment
+        #: Unless it is not associated with an account
         self.user = None
         if comment.get('user'):
             self.user = User(comment.get('user'), self)  # (No coverage)
